==> v4.8.12.zip: woocommerce-module/doc/FAQ/FAQ.md <==
## FAQ

**Ребрендинг модуля с RetailCRM на Simla.com**

Ребрендинг модуля WooCommerce связан с тем, что данные он востребован на зарубежном направлении и название нашей системы в Испании и ЛатАм - Simla.com. Для клиентов, которые работают с данным модулем CMS в РФ, ничего не меняется, модули будут также поддерживаться и развиваться.

Прошу обратить внимание, что в связи с ребрендингом изменилось название ICML-файла названия каталога - simla.xml *(ранее было retailcrm.xml)*.

Ребрендинг произошел в версии 4.3.0.

**Работа с более чем одним магазином в Woo**

В данный момент в модуле не предусмотрена работа с более чем 1 магазином в Woo. <br>
 
**Работа с одинаковыми позициями в заказе**
    
Модуль поддерживает работу с одинаковыми товарными позициями в заказе начиная с версии 3.5.4 <br>

**Изменения генерации ICML-файла**
В модуле возможно сделать необходимые кастомизация для генерации ICML-файла в желаемом формате <br>

**Выгрузка архивных данных** <br>
Ранее модуль *(до версии 4.3.3)* мог выгружать не более 700-800 архивных заказов *(т.к. выгрузка происходила по web-хиту, работа скрипта была ограничена и не все данные успевали прогрузится в CRM)*, этот момент был доработан *(#70113)* и сейчас модуль загружает из Woo в CRM все присутствующие заказы пачками по 50 шт *(сделано для того, чтобы у слабых серверов не возникало проблем с загрузкой)*.
Также заказы архивные данные можно выгрузить с использованием консольного скрипта: нужно скачать этот скрипт, загрузить его в корень сайта на сервере
**upload_to_crm.php**  *(название файла)*

    <?php
    /** Load WordPress Bootstrap **/
    require_once dirname( __FILE__ ) . '/wp-load.php';
    do_action("wp_ajax_do_upload");
После чего в командной строке ввести команду 

> php upload_to_crm.php

 тем самым запустить выполнение скрипта. Для последнего действия нужно использовать ssh.
После выполнения данных действий дожидаемся завершение работы. При этом информация об ошибках при выгрузке заказов будет фиксироваться в разделе WooCommerce "Статус", "Журналы".
Как скрипт завершит работу в командной строке появляется возможность ввести новую команду.

**Работа с зонами доставки**  *(WooCommerce - Настройки - Доставка - Зоны доставки)*
    
С зонами доставки модуль не работает

[https://github.com/retailcrm/woocommerce-module/blob/master/src/include/abstracts/class-wc-retailcrm-abstracts-settings.php#L256](https://github.com/retailcrm/woocommerce-module/blob/master/src/include/abstracts/class-wc-retailcrm-abstracts-settings.php#L256)

Как только появляются новые методы доставки они автоматически добавляются в настройки CRM. <br>

**Выгрузка вариативных товаров**
    
В модуле добавлен обработка всех типов товаров в WooCommerce. Раньше обрабатывались только variable/simple, теперь, если тип товара не является variation/variable + кастомные типы плагинов содержащие торговые предложения *(variable-subscription и т.п.)*, то обрабатываются как simple. Стандартные типы товаров обрабатываются корректно, но любые кастомные типы с плагинов все равно необходимо исследовать.

## Причины возникновения ошибок

**Не пришел заказ из Woo в CRM** <br>
Причина может быть в Методе оплаты. Если в настройках CRM *(Настройки - Справочники - Типы оплат)* в конкретном типе оплаты не выбран статус оплаты, с которым пришел заказ из CMS, то заказ не будет выгружен в CRM. Данная проблема должна решиться после реализации задачи [#73631](https://redmine.retailcrm.tech/issues/73631).

![](https://lh3.googleusercontent.com/v3W9GDMvBy9ASK6t27utB4PtsH0EkO7cxfG_317D4FWw3y5sWe9GaNeuJj_NmAR0pMLsJnAnBpCZtK3_yA2kAg50iwO2yV2m1zDfKdSYYSw-2PIXRv3j2r3d3BpaogvTS44OV1U0=s0)

 **Не выгрузились корп клиенты при архивной выгрузке** <br>
 Необходимо проверить включение данной опции в настройках модуля в WooCommerce.

**В CRM не отображаются остатки по товару** / **При создании заказа в CRM, товар не списывается со склада в Woocomerce** <br>
    
Необходимо выключить редактирование остатков в настройках CRM *(Настройки - Системные - Склад - Разрешить редактирование остатков)*. При включенной опции количество товаров из ICML-файла будет игнорироваться при загрузке. Также для магазина, привязанного к сайту Woo, должны быть разрешены все склады.

По решению проблемы должны немного помочь задачи [#54708](https://redmine.retailcrm.tech/issues/54708) и [#74803](https://redmine.retailcrm.tech/issues/74803).

  
**В CRM приходит оплаченный заказ, хотя в Woo оплаты не было** <br>
    
Требуется проверить активность опции “Оплата произведена” *(Настройки - Справочники - Статусы оплат)* в статусе оплаты, с которым приходит заказ в CRM.

**Когда заказ создается через Woocommerce, то ему на почту приходит вся информация по заказу, а если создается через CRM, то на почту приходит чаще всего приходит пустая карточка, но не всегда, от чего это может зависеть?**  <br>

Это не проблема, а логика работы нашего модуля. Модуль не отправляет письма, то есть в Woo сохраняется заказ без суммы (она проставляется чуть позже), но как только заказ появляется в Woo, срабатывает хук и отправляется письмо на email, как раз без суммы.

**Работоспособность модуля** <br>
На работоспособность модуля влияют: <br>
**1**) Оплата модуля Онлайн-консультанта. <br>
**2**) Для работы модуля требуются файлы generate_icml.php и retailcrm_history.php *(не удалять их)*.

**Ранее заказы могли не выгружаться из WooCommerce в CRM по причинам** *(сейчас заказы выгружаются, т.к. была убрана валидация)*: <br>

- **Отсутствовала страна в настройках**.  <br> Если в настройках CRM в списке доступных стран (Настройки - Системные - Общие - Список доступных стран) не была выбрана страна, указанная в выгружаемом заказе, то заказ не появлялся в CRM. После внедрения задачи [#74148](https://redmine.retailcrm.tech/issues/74148), заказы с неразрешенной страной приходят в CRM. При открытии карточки заказа, появляется pop-up с информацией о том, что указанную в заказе страну нужно добавить в настройках.

- **Неразрешенный способ оплаты в доставке**.  <br> Если в настройках CRM в справочниках Типов доставок (Настройки - Справочники - Типы доставок - перейти в конкретный справочник - вкладка Способы оплаты) не был разрешен способ оплаты для доставки, указанной в выгружаемом заказе, то заказ не приходил в CRM. После внедрения задачи [#71543](https://redmine.retailcrm.tech/issues/71543), заказы с неразрешенной оплатой для доставки, выгружаются в CRM. При заходе в карточку данного заказа, появляется pop-up с информацией о том, что для доставки требуется разрешить указанный метод оплаты.

### Не синхронизируется история изменений из Simla.com, не генерируется каталог или не синхронизируются остатки

Необходимо проверить, выполняет ли wp-cron задачи модуля. В разделе Debug настроек модуля должна быть указана текущая дата (+/- 4 часа).
Далее требуется проверить, что все задачи wp-cron выполняются на сайте. Для этого нужно перейти в раздел WooCommerce -> Статус (Estado) -> Статус системы (Estado del sistema) -> WordPress Cron (Cron de WordPress).

Если wp-cron не выполняет задачи, то в первую очередь нужно восстановить его работу.

Для быстрого решения можно перезапустить задачи wp-cron в настройках модуля, нажав на кнопку "Очистить" в блоке "Отладочная информация".

В некоторых случаях задачи модуля можно перенести на cron сервера. Имейте ввиду, что остальные задачи wp-cron останутся в таком же состоянии (не будут выполняться).
Действия для переноса:
- отключить wp-cron (см. инструкции по WooCommerce и WordPress),
- в зависимости от требуемых задач расположить в корневой директории сайта скрипты (в директории с файлом wp-config.php):

**simla_history.php** - для синхронизации истории
```
<?php

/** Load WordPress Bootstrap */
require_once dirname( __FILE__ ) . '/wp-load.php';

do_action("retailcrm_history");
```
**simla_icml.php** - для генерации каталога
```
<?php

/** Load WordPress Bootstrap */
require_once dirname( __FILE__ ) . '/wp-load.php';

do_action("retailcrm_icml");
```
**simla_stocks.php** - для синхронизации остатков
```
<?php

/** Load WordPress Bootstrap */
require_once dirname( __FILE__ ) . '/wp-load.php';

do_action("retailcrm_inventories");
```
- добавить нужные задачи в расписание cron сервера:
```
*/5 * * * *	{path to php} {wp dir}/simla_history.php
* */3 * * *	{path to php} {wp dir}/simla_icml.php
*/15 * * * *	{path to php} {wp dir}/simla_stocks.php
```
Пример:
```
*/5 * * * *	/usr/local/bin/php /home/conquero/public_html/simla_history.php
* */3 * * *	/usr/local/bin/php /home/my_site/public_html/simla_icml.php
*/15 * * * *	/usr/local/bin/php /home/conquero/public_html/simla_stocks.php
```

==> v4.8.18.zip: woocommerce-module/doc/FAQ/FAQ.md <==
## FAQ

**Ребрендинг модуля с RetailCRM на Simla.com**

Ребрендинг модуля WooCommerce связан с тем, что данные он востребован на зарубежном направлении и название нашей системы в Испании и ЛатАм - Simla.com. Для клиентов, которые работают с данным модулем CMS в РФ, ничего не меняется, модули будут также поддерживаться и развиваться.

Прошу обратить внимание, что в связи с ребрендингом изменилось название ICML-файла названия каталога - simla.xml *(ранее было retailcrm.xml)*.

Ребрендинг произошел в версии 4.3.0.

**Работа с более чем одним магазином в Woo**

В данный момент в модуле не предусмотрена работа с более чем 1 магазином в Woo. <br>
 
**Работа с одинаковыми позициями в заказе**
    
Модуль поддерживает работу с одинаковыми товарными позициями в заказе начиная с версии 3.5.4 <br>

**Изменения генерации ICML-файла**
В модуле возможно сделать необходимые кастомизация для генерации ICML-файла в желаемом формате <br>

**Выгрузка архивных данных** <br>

Ранее модуль мог выгружать не более 700-800 архивных заказов *(т.к. выгрузка происходила по web-хиту, работа скрипта была ограничена и не все данные успевали прогрузится в CRM)*.<br>
Сейчас архивные данные можно выгрузить в CRM с использованием консольного скрипта. Этот скрипт позволяет выгружать все архивные заказы и данные о клиентах без ограничения на количество записей. Процесс выгрузки выполняется пакетами по 50 заказов или 50 клиентов за раз. <br>
После завершения обработки каждой пачки выводится ее порядковый номер, что позволяет отслеживать прогресс работы скрипта. Если во время выгрузки возникает ошибка, скрипт можно перезапустить с той страницы, где произошел сбой, что минимизирует потерю данных и время на повторную выгрузку.<br>

Для запуска выгрузки нужно:<br>

1. В корневой директории вашего сайта (по умолчанию - */var/www/html*) разместить файл **upload_to_crm.php** и вставить в него код:

```
<?php

require_once __DIR__ . '/wp-load.php';

$options = getopt('',['entity::','page::']);

do_action('wp_console_upload', $options['entity'] ?? '', (int) $options['page'] ?? 0);
```
2. После чего в командной строке ввести команду для запуска скрипта: <br>

> php upload_to_crm.php --entity=orders/customers/full_upload --page=номер страницы

Параметры для выгрузки:<br>

**--entity**: Указывает, какие данные выгружать. Данный параметр **является обязательным**. Возможные значения:

- **orders**: архивные заказы;
- **customers**: архивные клиенты;
- **full_upload**: полная выгрузка всех заказов и клиентов (весь архив).

**--page**: Указывает номер страницы для выгрузки. Каждая страница содержит 50 заказов или клиентов. Нумерация страниц начинается с 0.<br>

Пример:

> php upload_to_crm.php --entity=orders --page=3

В этом примере будет выгружен архив заказов, начиная с 3-й страницы.

**Работа с зонами доставки** *(WooCommerce - Настройки - Доставка - Зоны доставки)*
    
С зонами доставки модуль не работает

[https://github.com/retailcrm/woocommerce-module/blob/master/src/include/abstracts/class-wc-retailcrm-abstracts-settings.php#L256](https://github.com/retailcrm/woocommerce-module/blob/master/src/include/abstracts/class-wc-retailcrm-abstracts-settings.php#L256)

Как только появляются новые методы доставки они автоматически добавляются в настройки CRM. <br>

**Выгрузка вариативных товаров**
    
В модуле добавлен обработка всех типов товаров в WooCommerce. Раньше обрабатывались только variable/simple, теперь, если тип товара не является variation/variable + кастомные типы плагинов содержащие торговые предложения *(variable-subscription и т.п.)*, то обрабатываются как simple. Стандартные типы товаров обрабатываются корректно, но любые кастомные типы с плагинов все равно необходимо исследовать.

## Причины возникновения ошибок

**Не пришел заказ из Woo в CRM** <br>
Причина может быть в Методе оплаты. Если в настройках CRM *(Настройки - Справочники - Типы оплат)* в конкретном типе оплаты не выбран статус оплаты, с которым пришел заказ из CMS, то заказ не будет выгружен в CRM. Данная проблема должна решиться после реализации задачи [#73631](https://redmine.retailcrm.tech/issues/73631).

![](https://lh3.googleusercontent.com/v3W9GDMvBy9ASK6t27utB4PtsH0EkO7cxfG_317D4FWw3y5sWe9GaNeuJj_NmAR0pMLsJnAnBpCZtK3_yA2kAg50iwO2yV2m1zDfKdSYYSw-2PIXRv3j2r3d3BpaogvTS44OV1U0=s0)

 **Не выгрузились корп клиенты при архивной выгрузке** <br>
 Необходимо проверить включение данной опции в настройках модуля в WooCommerce.

**В CRM не отображаются остатки по товару** / **При создании заказа в CRM, товар не списывается со склада в Woocomerce** <br>
    
Необходимо выключить редактирование остатков в настройках CRM *(Настройки - Системные - Склад - Разрешить редактирование остатков)*. При включенной опции количество товаров из ICML-файла будет игнорироваться при загрузке. Также для магазина, привязанного к сайту Woo, должны быть разрешены все склады.

По решению проблемы должны немного помочь задачи [#54708](https://redmine.retailcrm.tech/issues/54708) и [#74803](https://redmine.retailcrm.tech/issues/74803).

  
**В CRM приходит оплаченный заказ, хотя в Woo оплаты не было** <br>
    
Требуется проверить активность опции “Оплата произведена” *(Настройки - Справочники - Статусы оплат)* в статусе оплаты, с которым приходит заказ в CRM.

**Когда заказ создается через Woocommerce, то ему на почту приходит вся информация по заказу, а если создается через CRM, то на почту приходит чаще всего приходит пустая карточка, но не всегда, от чего это может зависеть?**  <br>

Это не проблема, а логика работы нашего модуля. Модуль не отправляет письма, то есть в Woo сохраняется заказ без суммы (она проставляется чуть позже), но как только заказ появляется в Woo, срабатывает хук и отправляется письмо на email, как раз без суммы.

**Работоспособность модуля** <br>
На работоспособность модуля влияют: <br>
**1**) Оплата модуля Онлайн-консультанта. <br>
**2**) Для работы модуля требуются файлы generate_icml.php и retailcrm_history.php *(не удалять их)*.

**Ранее заказы могли не выгружаться из WooCommerce в CRM по причинам** *(сейчас заказы выгружаются, т.к. была убрана валидация)*: <br>

- **Отсутствовала страна в настройках**.  <br> Если в настройках CRM в списке доступных стран (Настройки - Системные - Общие - Список доступных стран) не была выбрана страна, указанная в выгружаемом заказе, то заказ не появлялся в CRM. После внедрения задачи [#74148](https://redmine.retailcrm.tech/issues/74148), заказы с неразрешенной страной приходят в CRM. При открытии карточки заказа, появляется pop-up с информацией о том, что указанную в заказе страну нужно добавить в настройках.

- **Неразрешенный способ оплаты в доставке**.  <br> Если в настройках CRM в справочниках Типов доставок (Настройки - Справочники - Типы доставок - перейти в конкретный справочник - вкладка Способы оплаты) не был разрешен способ оплаты для доставки, указанной в выгружаемом заказе, то заказ не приходил в CRM. После внедрения задачи [#71543](https://redmine.retailcrm.tech/issues/71543), заказы с неразрешенной оплатой для доставки, выгружаются в CRM. При заходе в карточку данного заказа, появляется pop-up с информацией о том, что для доставки требуется разрешить указанный метод оплаты.

### Не синхронизируется история изменений из Simla.com, не генерируется каталог или не синхронизируются остатки

Необходимо проверить, выполняет ли wp-cron задачи модуля. В разделе Debug настроек модуля должна быть указана текущая дата (+/- 4 часа).
Далее требуется проверить, что все задачи wp-cron выполняются на сайте. Для этого нужно перейти в раздел WooCommerce -> Статус (Estado) -> Статус системы (Estado del sistema) -> WordPress Cron (Cron de WordPress).

Если wp-cron не выполняет задачи, то в первую очередь нужно восстановить его работу.

Для быстрого решения можно перезапустить задачи wp-cron в настройках модуля, нажав на кнопку "Очистить" в блоке "Отладочная информация".

В некоторых случаях задачи модуля можно перенести на cron сервера. Имейте ввиду, что остальные задачи wp-cron останутся в таком же состоянии (не будут выполняться).
Действия для переноса:
- отключить wp-cron (см. инструкции по WooCommerce и WordPress),
- в зависимости от требуемых задач расположить в корневой директории сайта скрипты (в директории с файлом wp-config.php):

**simla_history.php** - для синхронизации истории
```
<?php

/** Load WordPress Bootstrap */
require_once dirname( __FILE__ ) . '/wp-load.php';

do_action("retailcrm_history");
```
**simla_icml.php** - для генерации каталога
```
<?php

/** Load WordPress Bootstrap */
require_once dirname( __FILE__ ) . '/wp-load.php';

do_action("retailcrm_icml");
```
**simla_stocks.php** - для синхронизации остатков
```
<?php

/** Load WordPress Bootstrap */
require_once dirname( __FILE__ ) . '/wp-load.php';

do_action("retailcrm_inventories");
```
- добавить нужные задачи в расписание cron сервера:
```
*/5 * * * *	{path to php} {wp dir}/simla_history.php
* */3 * * *	{path to php} {wp dir}/simla_icml.php
*/15 * * * *	{path to php} {wp dir}/simla_stocks.php
```
Пример:
```
*/5 * * * *	/usr/local/bin/php /home/conquero/public_html/simla_history.php
* */3 * * *	/usr/local/bin/php /home/my_site/public_html/simla_icml.php
*/15 * * * *	/usr/local/bin/php /home/conquero/public_html/simla_stocks.php
```
